@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package WWW::curlmyip;
-$WWW::curlmyip::VERSION = '0.02';
+$WWW::curlmyip::VERSION = '0.03';
 use HTTP::Tiny;
 use 5.008;
 
@@ -17,7 +17,7 @@ BEGIN {
 
 
 sub get_ip {
-    my $response = HTTP::Tiny->new->get('http://curlmyip.com');
+    my $response = HTTP::Tiny->new(timeout => 3)->get('http://curlmyip.com');
     die join(' ', 'Error fetching ip: ',
                   ($response->{status} or ''),
                   ($response->{reason} or '')) unless $response->{success};
@@ -40,7 +40,7 @@ WWW::curlmyip - Returns your ip address using L<http://curlmyip.com>
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -63,11 +63,11 @@ Returns your ip address, using L<http://curlmyip.com>.
 
 =head1 AUTHOR
 
-David Farrell <sillymoos@cpan.org>
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2015 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
